@@ -1,4 +1,4 @@
 __version__ = "0.0.1"
 
 # 可外部调用的包的函数
-from elogger.log import *
+from eqlog.log import *
